// ================================================
// ForecastArea
// ================================================
function ForecastArea(prefNum, sectionNum, cityNum) {
	LOG2__("Object: ForecastArea");
	this.pref = null;
	this.section = null;
	this.city = null;
	this.prefCode = null;
	this.prefName = null;
	this.prefSName = null;
	this.prefData = null;

	// Set pref, section, and city
	//   Default area is Tokyo (area:18, section:0, city:0)
	var newPrefNum    = (prefNum != null)?    prefNum : 18;
	var newSectionNum = (sectionNum != null)? sectionNum : 0;
	var newCityNum    = (cityNum != null)?    cityNum : 0;

	this.setAreaWithCode(newPrefNum, newSectionNum, newCityNum);
}

// Set pref, section, and city
ForecastArea.prototype.setArea = function(theArea) {
	LOG2__("ForecastArea.setArea(theArea)");
	this.setAreaWithCode(theArea.pref, theArea.section, theArea.city);
}

ForecastArea.prototype.setAreaWithCode = function(prefNum, sectionNum, cityNum) {
	LOG2__("ForecastArea.setAreaWithCode(" + prefNum + ", " + sectionNum + ", " + cityNum + ")");
	this.setPref(prefNum);
	this.setSection(sectionNum);
	this.setCity(cityNum);
}

ForecastArea.prototype.setPref = function(prefNum) {
	LOG3__("ForecastArea.setPref(" + prefNum + ")");

	// Prepare the pref data
	this.prefCode = areaDictionary.prefs[prefNum].code;
	this.prefName = areaDictionary.prefs[prefNum].name;
	this.prefSName = areaDictionary.prefs[prefNum].sName;
	this.prefData = areaDictionary.prefs[prefNum].array;

	this.pref = prefNum;
}

ForecastArea.prototype.setSection = function(sectionNum) {
	LOG3__("ForecastArea.setSection(" + sectionNum + ")");
	var numOfSections = this.prefData.length;

	// Correct the section number
	if (!((0 <= sectionNum) && (sectionNum < numOfSections))) {
		LOG2__("ForecastArea.setSection: section "  + sectionNum + " corrected to 0");
		sectionNum = 0;
	}

	this.section = sectionNum;
}

ForecastArea.prototype.setCity = function(cityNum) {
	LOG3__("ForecastArea.setCity(" + cityNum + ")");
	var numOfCities = this.prefData[this.section].city.length;

	// Correct the city number
	if (!((0 <= cityNum) && (cityNum < numOfCities))) {
		LOG2__("ForecastArea.setCity: city "  + cityNum + " corrected to 0");
		cityNum = 0;
	}

	this.city = cityNum;
}

// Name of pref for displaying
ForecastArea.prototype.stringPref = function() {
	return ((!this.prefSName)? this.prefName : this.prefSName);
}

// Name of section for displaying
ForecastArea.prototype.stringSection = function() {
	var location = "";

	if (!this.prefSName) {
		if (this.prefData[this.section].name != this.prefName)
			location = this.prefData[this.section].name;
	} else {
		if (this.prefData[this.section].name != this.prefSName)
			location = this.prefData[this.section].name;
	}

	return location;
}

// Name of city for displaying
ForecastArea.prototype.stringCity = function() {
	return this.prefData[this.section].city[this.city];
}

// Name of section for displaying a week forecast
ForecastArea.prototype.stringWSection = function(data7Length) {
	var location = this.prefData[this.section]["wName" + data7Length];
	return ((location != this.stringPref())? location : "");
}

// Compare to another area
ForecastArea.prototype.isEqualTo = function(theArea) {
	// If the area is not set, return false
	if ((this.pref == null) || (this.section == null) || (this.city == null))
		return false;

	// If another area is not set, return false
	if (theArea == null)
		return false;
	if ((theArea.pref == null) || (theArea.section == null) || (theArea.city == null))
		return false;

	return (
		(this.pref    == theArea.pref) &&
		(this.section == theArea.section) &&
		(this.city    == theArea.city)
	);
}
